# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from agatha_protobuf.analysis import analysis_pb2 as agatha__protobuf_dot_analysis_dot_analysis__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in agatha_protobuf/analysis/analysis_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AnalysisServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/analysis.AnalysisService/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.HealthCheckResponse.FromString,
                _registered_method=True)
        self.AnalyzeText = channel.unary_unary(
                '/analysis.AnalysisService/AnalyzeText',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeResponse.FromString,
                _registered_method=True)
        self.AnalyzeTextFromLLMS = channel.unary_unary(
                '/analysis.AnalysisService/AnalyzeTextFromLLMS',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeLLMSResponse.FromString,
                _registered_method=True)
        self.CreateFeedback = channel.unary_unary(
                '/analysis.AnalysisService/CreateFeedback',
                request_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateFeedbackRequest.SerializeToString,
                response_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeResponse.FromString,
                _registered_method=True)


class AnalysisServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AnalyzeText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AnalyzeTextFromLLMS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalysisServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.HealthCheckResponse.SerializeToString,
            ),
            'AnalyzeText': grpc.unary_unary_rpc_method_handler(
                    servicer.AnalyzeText,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeResponse.SerializeToString,
            ),
            'AnalyzeTextFromLLMS': grpc.unary_unary_rpc_method_handler(
                    servicer.AnalyzeTextFromLLMS,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeLLMSResponse.SerializeToString,
            ),
            'CreateFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeedback,
                    request_deserializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateFeedbackRequest.FromString,
                    response_serializer=agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'analysis.AnalysisService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('analysis.AnalysisService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AnalysisService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.HealthCheckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AnalyzeText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/AnalyzeText',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AnalyzeTextFromLLMS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/AnalyzeTextFromLLMS',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeLLMSResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analysis.AnalysisService/CreateFeedback',
            agatha__protobuf_dot_analysis_dot_analysis__pb2.CreateFeedbackRequest.SerializeToString,
            agatha__protobuf_dot_analysis_dot_analysis__pb2.AnalyzeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
